@@ -8,6 +8,10 @@ import os
 from . import pyglass
 
 
+# Initialize the web service
+pyglass.Service.GetInstance().Init(2, pyglass.ConnectionSettings())
+
+
 class Block:
     """
     Instances of this class represent blocks of volumetric image data. These
@@ -1178,6 +1182,187 @@ class Project:
         """
         self.impl.CopyShaderSettingsFromProject(source.impl)
 
+    @_closed_project_decorator
+    def rename_mesh(self, old_name: str, new_name: str, experiment: str = 'default') -> None:
+        """
+        Renames a mesh in the experiment.
+
+        :param old_name: the current name of the mesh
+        :param new_name: the name to rename the mesh to
+        :param experiment: the name of the experiment where the mesh exists
+        """
+        mesh_dict = self.impl.GetMeshNamesAndSizes(experiment).asdict()
+        mesh_names = mesh_dict.keys()
+        if old_name in mesh_names:
+            self.impl.RenameMesh(experiment, old_name, new_name)
+        else:
+            raise KeyError("Surface not in experiment " + experiment)
+
+    @_closed_project_decorator
+    def randomize_mesh_colors(self, experiment: str = 'default') -> None:
+        """
+        Randomizes the colors of meshes in a project.
+
+        :param experiment: the name of the experiment where the meshes exist
+        """
+        db = self.impl.GetDBAccessor()
+        experiments = list(db.GetDirectories())
+        if experiment in experiments:
+            self.impl.RandomizeMeshColors(experiment)
+        else:
+            raise KeyError("Experiment " + experiment + " not in project")
+
+    @_closed_project_decorator
+    def set_sample_weight(self, sample_weight: float) -> None:
+        """
+        Sets the weight, in grams, of the entire imaged sample.
+
+        :param sample_weight: the weight to set the sample weight to
+        """
+        if sample_weight >= 0:
+            self.impl.SetSampleWeight(sample_weight)
+        else:
+            raise ValueError("Weight must be greater than 0")
+
+    @_closed_project_decorator
+    def set_mesh_label_opacity(self, label: str, opacity: float, experiment: str = 'default') -> None:
+        """
+        Sets the opacity of a mesh label in the experiment.
+
+        :param label: the name of the label to set the opacity of
+        :param opacity: a float value representing opacity
+        :param experiment: the name of the experiment where the label exists
+        """
+        tags = list(self.impl.GetTags(experiment))
+        hasTag = False
+        for tag in tags:
+            if label == tag:
+                hasTag = True
+                break
+        if hasTag:
+            if (opacity >= 0.0) and (opacity <= 100.0):   
+                self.impl.SetTagOpacity(experiment, label, opacity)
+            else:
+                raise ValueError("Opacity must be between 0 and 100")
+        else:
+            raise KeyError("Label " + label + " not in experiment " + experiment)
+
+    @_closed_project_decorator
+    def get_number_of_counting_points(self, experiment: str = 'default') -> int:
+        """
+        Returns the number of points associated with the given experiment.
+
+        :param experiment: the name of the experiment from which to retrieve
+                           counting points
+        :return: the number of counting points as an integer
+        """
+        return self.impl.GetNumberOfCounts(experiment)
+
+    @_closed_project_decorator
+    def get_number_of_measurements(self, experiment: str = 'default') -> int:
+        """
+        Returns the number of measurements associated with the given experiment.
+
+        :param experiment: the name of the experiment from which to retrieve
+                           measurements
+        :return: the number of measurements as an integer
+        """
+        return self.impl.GetNumberOfMeasurements(experiment)
+
+    @_closed_project_decorator
+    def get_number_of_multivariate_data_points(self, experiment: str = 'default') -> int:
+        """
+        Returns the number of multivariate data points associated with the given experiment.
+
+        :param experiment: the name of the experiment from which to retrieve
+                           multivariate data points
+        :return: the number of multivariate data points as an integer
+        """
+        return self.impl.GetNumberOfMVDPoints(experiment)
+
+    @_closed_project_decorator
+    def get_number_of_multi_tracking_series(self, experiment: str = 'default') -> int:
+        """
+        Returns the number of multi-tracking series associated with the given experiment.
+
+        :param experiment: the name of the experiment from which to retrieve
+                           multi-tracking series
+        :return: the number of multi-tracking series as an integer
+        """
+        return self.impl.GetNumberOfOnionSeries(experiment)
+
+    @_closed_project_decorator
+    def get_number_of_tracing_nodes(self, experiment: str = 'default') -> int:
+        """
+        Returns the number of tracing nodes associated with the given experiment.
+
+        :param experiment: the name of the experiment from which to retrieve
+                           tracing nodes
+        :return: the number of tracing nodes as an integer
+        """
+        return self.impl.GetNumberOfSkeletonNodes(experiment)
+
+    @_closed_project_decorator
+    def get_number_of_tracking_points(self, experiment: str = 'default') -> int:
+        """
+        Returns the number of tracking points associated with the given experiment.
+
+        :param experiment: the name of the experiment from which to retrieve
+                           tracking points
+        :return: the number of tracking points as an integer
+        """
+        return self.impl.GetNumberOfTraces(experiment)
+
+    @_closed_project_decorator
+    def delete_counting_points(self, experiment: str = 'default') -> None:
+        """
+        Deletes counting points associated with given experiment.
+
+        :param experiment: the name of the experiment from which to delete
+                           counting points
+        """
+        self.impl.DeleteCounts(experiment)
+
+    @_closed_project_decorator
+    def dvid_delete_label(self, label: str, experiment: str = 'default') -> None:
+        """
+        Deletes label associated with given experiment.
+
+        :param label: the name of the label
+        :param experiment: the name of the experiment from which to delete
+                           label
+        """
+        self.impl.DeleteLabel(experiment, label)
+
+    @_closed_project_decorator
+    def delete_multivariate_data(self, experiment: str = 'default') -> None:
+        """
+        Deletes multivariate data associated with given experiment.
+
+        :param experiment: the name of the experiment from which to delete
+                           multivariate data
+        """
+        self.impl.DeleteMultivariateData(experiment)
+
+    @_closed_project_decorator
+    def delete_multi_tracking_series(self, experiment: str = 'default') -> None:
+        """
+        Deletes all multi-tracking series associated with given experiment.
+
+        :param experiment: the name of the experiment from which to delete
+                           onion series
+        """
+        self.impl.DeleteOnionSeries(experiment)
+
+    @_closed_project_decorator
+    def delete_tracking_points(self, experiment: str = 'default') -> None:
+        """
+        Deletes all tracking points associated with given experiment.
+
+        :param experiment: the name of the experiment from which to delete
+                           tracking points
+        """
+        self.impl.DeleteTraces(experiment)
 
 class ProjectCreationSettings:
     """
